(function() {
	/*****************************************************
	 * WiFi
	 * アクセスポイントの各種情報取得を行う(Androidのみ)
	 *****************************************************/

	/*
	 * 周囲にあるアクセスポイントのSSID一覧を取得
	 */
	getSSIDList = function() {
		event.preventDefault();
		applican.wifi.getSSIDList(getSSIDListSuccess, getSSIDListError);
	};

	/*
	 * 周囲にあるアクセスポイントのSSID一覧を取得成功した時のコールバック
	 * result : SSIDの配列
	 */
	getSSIDListSuccess = function(result) {
		var dump = "周囲にあるアクセスポイントのSSID一覧を取得成功しました。\n";
		var numSSID = result.length;
		dump += "num: " + numSSID + "\n";

		for(var i = 0; i < numSSID; i++) {
			dump += "SSID: " + result[i] + "\n";
		}
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 周囲にあるアクセスポイントのSSID一覧を取得失敗した時のコールバック
	 * err.code : エラーコード
	 * 			PERMISSION_DENIED	パーミッションエラー
	 * 			UNKNOWN_ERROR		不明なエラー
	 * 			DISCONNECT			WiFiが無効
	 * 			ILLEGAL_PARAMETER	不正なパラメータ
	 * 			CONNECT_FAILED		接続失敗(APが無い、パスワード誤りなど)
	 */
	getSSIDListError = function(err) {
		var dump = "周囲にあるアクセスポイントのSSID一覧を取得失敗しました。\n";
		dump    += "エラーコード: " + err.code + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 現在接続中のSSIDを取得
	 */
	getCurrentSSID = function() {
		event.preventDefault();
		applican.wifi.getCurrentSSID(getCurrentSSIDSuccess, getCurrentSSIDError);
	};

	/*
	 * 現在接続中のSSIDを取得成功した時のコールバック
	 * result : SSID
	 */
	getCurrentSSIDSuccess = function(result) {
		var dump = "現在接続中のSSIDを取得成功しました。\n";
		dump    += "SSID: " + result +"\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 現在接続中のSSIDを取得失敗した時のコールバック
	 * err.code : エラーコード
	 * 			PERMISSION_DENIED	パーミッションエラー
	 * 			UNKNOWN_ERROR		不明なエラー
	 * 			DISCONNECT			WiFiが無効
	 * 			ILLEGAL_PARAMETER	不正なパラメータ
	 * 			CONNECT_FAILED		接続失敗(APが無い、パスワード誤りなど)
	 */
	getCurrentSSIDError = function(err) {
		var dump = "現在接続中のSSIDを取得失敗しました。\n";
		dump    += "code: " + err.code + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 現在接続中のIPアドレスを取得
	 */
	getCurrentIPv4Address = function() {
		event.preventDefault();
		applican.wifi.getCurrentIPv4Address(getCurrentIPv4AddressSuccess, getCurrentIPv4AddressError);
	};

	/*
	 * 現在接続中のIPアドレスを取得成功した時のコールバック
	 * result : IP Address
	 */
	getCurrentIPv4AddressSuccess = function(result) {
		var dump = "現在接続中のIPアドレスを取得成功しました\n";
		dump    += "IP Address: " + result + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 現在接続中のIPアドレスを取得失敗した時のコールバック
	 * result : IP Address
	 */
	getCurrentIPv4AddressError = function(err) {
		var dump = "現在接続中のIPアドレスを取得失敗しました。\n";
		dump    += "code: " + err.code + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 周囲にあるアクセスポイントの詳細情報を取得
	 */
	getAccessPointList = function() {
		event.preventDefault();
		applican.wifi.getAccessPointList(getAccessPointListSuccess, getAccessPointListError);
	};

	/*
	 * 周囲にあるアクセスポイントの詳細情報を取得成功した時のコールバック
	 * result[] : アクセスポイント情報
	 * result[].bssid			MACアドレス
	 * result[].ssid			SSID
	 * result[].level			信号強度(dBm)
	 * result[].frequency		周波数(MHz)
	 * result[].capabilitie		暗号化情報
	 */
	getAccessPointListSuccess = function(result) {
		var dump = "周囲にあるアクセスポイントの詳細情報を取得成功しました。\n";
		var numAccessPoint = result.length;
		dump += "num: " + numAccessPoint + "\n";
		for(var i = 0; i < numAccessPoint; i++) {
			dump += "-----------\n";
			dump += "ssid : "         + result[i].ssid         + "\n";
			dump += "bssid : "        + result[i].bssid        + "\n";
			dump += "level : "        + result[i].level        + "\n";
			dump += "capabilities : " + result[i].capabilities + "\n";
			dump += "frequency : "    + result[i].frequency    + "\n";
		}
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 周囲にあるアクセスポイントの詳細情報を取得失敗した時のコールバック
	 * err.code : エラーコード
	 */
	getAccessPointListError = function(err) {
		var dump = "周囲にあるアクセスポイントの詳細情報を取得失敗しました。\n";
		dump += "エラーコード: " + err.code + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * Wifiの接続履歴を取得
	 */
	getConfiguredNetworks = function() {
		event.preventDefault();
		applican.wifi.getConfiguredNetworks(getConfiguredNetworksSuccess, getConfiguredNetworksError);
	};

	/*
	 * Wifiの接続履歴を取得成功した時のコールバック
	 * result[] : アクセスポイント情報
	 * result[].ssid          SSID
	 * result[].status        状態(CURRENT:接続中、ENABLED:接続可能、DISABLED:接続不可)
	 * result[].networkId     Androidシステム上の通番
	 */
	getConfiguredNetworksSuccess = function(result) {
		var dump = "Wifiの接続履歴を取得成功しました。\n";
		var numAccessPoint = result.length;
		dump += "num: " + numAccessPoint + "\n";
		for(var i = 0; i < numAccessPoint; i++) {
			dump += "-----------\n";
			dump += "ssid: "      + result[i].ssid      + "\n";
			dump += "networkId: " + result[i].networkId + "\n";
			dump += "status: "    + result[i].status    + "\n";
		}
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * Wifiの接続履歴を取得失敗した時のコールバック
	 * err.code : エラーコード
	 */
	getConfiguredNetworksError = function(err) {
		var dump = "Wifiの接続履歴を取得失敗しました。\n";
		dump    += "エラーコード: " + err.code + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 接続したことがあるSSIDかどうかを判別
	 */
	wifiHadConnected = function() {
		event.preventDefault();
		applican.wifi.hadConnected("myWiFi", wifiHadConnectedSuccess, wifiHadConnectedError);
	};

	/*
	 * 接続したことがあるSSIDかどうかを判別成功した時のコールバック
	 * result : true／false
	 */
	wifiHadConnectedSuccess = function(result) {
		var dump = "接続したことがあるSSIDかどうかを判別成功しました。\n";
		dump    += "result: " + result + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/*
	 * 接続したことがあるSSIDかどうかを判別失敗した時のコールバック
	 * err.code : エラーコード
	 */
	wifiHadConnectedError = function(err) {
		var dump = "接続したことがあるSSIDかどうかを判別失敗しました。\n";
		dump    += "エラーコード: " + err.code + "\n";
		document.getElementById("dumpAreaWiFiSetting").value = dump;
	};

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「周囲のSSID一覧を取得」ボタン押下処理
		document.getElementById("getSSIDListBtn").addEventListener("touchend", getSSIDList, false);
		// 「現在接続中のSSIDを取得(iOSも対応)」ボタン押下処理
		document.getElementById("getCurrentSSIDBtn").addEventListener("touchend", getCurrentSSID, false);
		// 「現在接続中のIPアドレスを取得(iOSも対応)」ボタン押下処理
		document.getElementById("getCurrentIPv4AddressBtn").addEventListener("touchend", getCurrentIPv4Address, false);
		// 「周囲のアクセスポイント一覧を取得」ボタン押下処理
		document.getElementById("getAccessPointListBtn").addEventListener("touchend", getAccessPointList, false);
		// 「WiFi設定情報を取得」ボタン押下処理
		document.getElementById("getConfiguredNetworksBtn").addEventListener("touchend", getConfiguredNetworks, false);
		// 「過去接続したかどうか」ボタン押下処理
		document.getElementById("wifiHadConnectedBtn").addEventListener("touchend", wifiHadConnected, false);
	}, false);
})();
